%% Analysis of flight path during vs after calls
clearvars; clc;
cd('D:\PhD Files\Flightspeak Project');
load cleanData;
timestamps = readmatrix('callResponseTimes.csv');
radio = readmatrix('radioCallData.csv');
esl_index = [0; 0; 1; 1; 1; 1; 1; 1; 0; 1; 1; 0; 0; 0; 0];
%% For each condition, ID section of interest and collect heading error
save = 1;
margin = 5; % How many degrees is considered close enough to target

error_mat = NaN(size(part_index, 1), 13);
error_3part = NaN(size(part_index, 1), 6, 3);
response_cell = cell(size(part_index, 1), 1);
rad_cell = cell(size(part_index, 1), 1);
error_cell = cell(size(part_index, 1), 1);
error3_cell = cell(size(part_index, 1), 1);
for part = 1:size(part_index, 1)
    part_name = strcat('P', num2str(part_index(part)));
    part_cell = cell(3, 2);
    rad_part = cell(3, 2);
    error_part = cell(3, 2);
    error3_part = cell(3, 2);
    for flight = 1:3
        flight_name = strcat('F', num2str(flight));
        for cond = 1:2
            if cond == 1
                cond_name = 'A';
            else
                cond_name = 'B';
            end
            data = Trunc.(char(part_name)).(char(flight_name)).(char(cond_name));
            if numel(data) > 0
                cond_times = timestamps(timestamps(:, 1) == flight & timestamps(:, 2) == cond, :);
                change_i = find(cond_times(:, 10) == 1);
                change_n = size(change_i, 1);
                cond_means = NaN(change_n, 2);
                cond_3part = NaN(change_n, 3);
                cond_responses = NaN(change_n, 3);
                rad_responses = NaN(change_n, 1);
                cond_rad = radio(radio(:, 1) == part_index(part) & radio(:, 2) == flight...
                    & radio(:, 3) == cond & radio(:, 4), :);
                for sect = 1:change_n
                    call_start = cond_times(change_i(sect), 4);
                    call_end = cond_times(change_i(sect), 5);
                    resp_start = cond_times(change_i(sect), 6);
                    if change_i(sect) == size(cond_times, 1)
                        resp_end = cond_times(change_i(sect), 7);
                        rad_end = size(cond_rad);
                    elseif cond_times(change_i(sect) + 1, 10) == 1
                        resp_end = cond_times(change_i(sect), 7);
                        rad_end = sect + 1;
                    elseif size(cond_times, 1) - change_i(sect) == 1
                        resp_end = 9999;
                        rad_end = size(cond_rad);
                    else
                        resp_end = cond_times(change_i(sect) + 2, 4);
                        rad_end = sect + 2;
                    end
                    call_heading = cond_times(change_i(sect), 8);
                    resp_heading = cond_times(change_i(sect), 9);
                    c_data_start = find(data(:, 1) >= call_start, 1, 'first');
                    c_data_end = find(data(:, 1) < call_end, 1, 'last');
                    r_data_start = find(data(:, 1) >= resp_start, 1, 'first');
                    if resp_end == 9999
                        r_data_end = size(data, 1);
                    else
                        r_data_end = find(data(:, 1) < resp_end, 1, 'last');
                    end
                    call_data = data(c_data_start:c_data_end, :);
                    resp_data = data(r_data_start:r_data_end, :);
                    call_error = abs(call_data(:, 5) - call_heading);
                    resp_error = abs(resp_data(:, 5) - resp_heading);
                    
                    % Take smaller response sections
                    c_data_length = c_data_end - c_data_start + 1;
                    if numel(resp_data) > 0
                        if size(resp_error, 1) <= c_data_length * 2
                            r1_error = resp_error(1:floor(size(resp_error, 1) * 0.5), :);
                            r2_error = resp_error(floor(size(resp_error, 1) * 0.5) + 1:end, :);
                        else
                            r1_error = resp_error(1:c_data_length, :);
                            r2_error = resp_error(end - (c_data_length - 1):end, :);
                        end
                    else
                        r1_error = NaN;
                        r2_error = NaN;
                    end
                    
                    cond_means(sect, 1) = nanmean(call_error);
                    cond_means(sect, 2) = nanmean(resp_error);
                    cond_3part(sect, 1) = nanmean(call_error);
                    cond_3part(sect, 2) = nanmean(r1_error);
                    cond_3part(sect, 3) = nanmean(r2_error);
                    
                    % Collect trial completion time
                    trial_correct = resp_error <= margin;
                    
                    if numel(resp_error) > 0
                        cond_responses(sect, 2) = min(resp_error);
                        if sum(trial_correct) > 0
                            cond_responses(sect, 1) = 1;
                            finish_i = find(resp_error <= margin, 1, 'first');
                            finish_time = resp_data(finish_i, 1);
                            cond_responses(sect, 3) = finish_time - resp_data(1, 1);
                        else
                            cond_responses(sect, 1) = 0;
                            cond_responses(sect, 3) = NaN;
                        end
                    end
                    
                    % Collect verbal response data
                    sect_rad = cond_rad(sect:rad_end, 5);
                    rad_acc = nanmean(sect_rad);
                    rad_responses(sect, 1) = rad_acc;
                end
            end
            error_mat(part, 1) = part_index(part);
            call_cell = ((flight - 1) * 4 + (cond * 2) - 1) + 1;
            resp_cell = ((flight - 1) * 4 + (cond * 2) + 1);
            if numel(data) > 0
                error_mat(part, call_cell) = nanmean(cond_means(:, 1));
                error_mat(part, resp_cell) = nanmean(cond_means(:, 2));
                error_3part(part, ((cond - 1) * 3) + 1, flight) = nanmean(cond_3part(:, 1));
                error_3part(part, ((cond - 1) * 3) + 2, flight) = nanmean(cond_3part(:, 2));
                error_3part(part, ((cond - 1) * 3) + 3, flight) = nanmean(cond_3part(:, 3));
            else
                error_mat(part, call_cell) = NaN;
                error_mat(part, resp_cell) = NaN;
            end
            part_cell{flight, cond} = cond_responses;
            rad_part{flight, cond} = rad_responses;
            error_part{flight, cond} = cond_means;
            error3_part{flight, cond} = cond_3part;
            % This is where I collect verbal response accuracy data from
            % some other source and combine it with the "cond_means" data.
            % I also have to save it so I can correlate heading error with
            % verbal response accuracy by section
        end
    end
    response_cell{part} = part_cell;
    rad_cell{part} = rad_part;
    error_cell{part} = error_part;
    error3_cell{part} = error3_part;
end

Cells.Response = response_cell;
Cells.Radio = rad_cell;
Cells.Error = error_cell;
Cells.Error3 = error3_cell;

cd('D:\PhD Files\Flightspeak Project\Saved CSV\Final');

varnames = {'Part', 'ESL', 'F1A_C', 'F1A_R', 'F1B_C', 'F1B_R', 'F2A_C', 'F2A_R',...
    'F2B_C', 'F2B_R', 'F3A_C', 'F3A_R', 'F3B_C', 'F3B_R'};
savetable = array2table([error_mat(:, 1) esl_index error_mat(:, 2:end)], 'VariableNames', varnames);

varnames3 = {'Part', 'ESL', 'F1A_C', 'F1A_R1', 'F1A_R2', 'F1B_C', 'F1B_R1', 'F1B_R2',...
    'F2A_C', 'F2A_R1', 'F2A_R2', 'F2B_C', 'F2B_R1', 'F2B_R2', 'F3A_C', 'F3A_R1',...
    'F3A_R2', 'F3B_C', 'F3B_R1', 'F3B_R2'};
savedata = reshape(error_3part, size(part_index, 1), []);
savedata = [part_index savedata];
savetable3 = array2table([savedata(:, 1) esl_index savedata(:, 2:end)], 'VariableNames', varnames3);
if save == 1
    writetable(savetable, 'callResponseError.csv');
    writetable(savetable3, 'callResponse3Part.csv');
end
fprintf('Error data calculated\n');
rt_data = NaN(size(part_index, 1), 7);
acc_data = NaN(size(part_index, 1), 7);
rad_data = NaN(size(part_index, 1), 7);
for part = 1:size(part_index, 1)
    rt_data(part, 1) = part_index(part);
    acc_data(part, 1) = part_index(part);
    rad_data(part, 1) = part_index(part);
    for flight = 1:3
        for cond = 1:2
            cond_cell = (flight - 1) * 2 + cond;
            data = response_cell{part}{flight, cond};
            rt_data(part, cond_cell + 1) = nanmean(data(:, 3));
            acc_data(part, cond_cell + 1) = (sum(data(:, 1)) / sum(~isnan(data(:, 1)))) * 100;
            rad = rad_cell{part}{flight, cond};
            rad_data(part, cond_cell + 1) = nanmean(rad(:));
        end
    end
end
varnames_resp = {'Part', 'ESL', 'F1A', 'F1B', 'F2A', 'F2B', 'F3A', 'F3B'};
varnames_rad = {'Part', 'ESL', 'Rad_F1A', 'Rad_F1B', 'Rad_F2A', 'Rad_F2B',...
    'Rad_F3A', 'Rad_F3B'};
rt_table = array2table([rt_data(:, 1) esl_index rt_data(:, 2:end)], 'VariableNames', varnames_resp);
acc_table = array2table([acc_data(:, 1) esl_index acc_data(:, 2:end)], 'VariableNames', varnames_resp);
rad_table = array2table([rad_data(:, 1) esl_index rad_data(:, 2:end)], 'VariableNames', varnames_rad);
if save == 1
    writetable(rt_table, 'responseTimes.csv');
    writetable(acc_table, 'responseAcc.csv');
    writetable(rad_table, 'radioAcc.csv');
end
cd('D:\PhD Files\Flightspeak Project');
fprintf('Response data calculated\n');
%% Run correlations of radio accuracy against other dependent variables
Corrs.Response = NaN(12, 3);
Corrs.Error = NaN(12, 2);
Corrs.Error3 = NaN(12, 3);
for dv = {'Response', 'Error', 'Error3'}
    data = vertcat(Cells.(char(dv)){:});
    rad = vertcat(Cells.Radio{:});
    for flight = 1:3
        for cond = 1:2
            cond_data = vertcat(data{flight:3:end, cond});
            cond_rad = vertcat(rad{flight:3:end, cond});
            for row = 1:size(cond_data, 2)
                [r, p] = corrcoef(cond_data(:, row), cond_rad, 'Rows', 'Complete');
                placement = (flight - 1) * 4 + (cond - 1) * 2;
                Corrs.(char(dv))(placement + 1, row) = r(2, 1);
                Corrs.(char(dv))(placement + 2, row) = p(2, 1);
            end
        end
    end
end